## cdist-type__apt_update_index(7)

### Steven Armstrong

`<steven-cdist--@--armstrong.cc>`

## 1. NAME

cdist-type__apt_update_index - Update apt’s package index

## 2. DESCRIPTION

This cdist type runs apt-get update whenever any apt sources have changed.

## 3. REQUIRED PARAMETERS

None.

## 4. OPTIONAL PARAMETERS

None.

## 5. EXAMPLES

    __apt_update_index

## 6. SEE ALSO

- cdist-type(7)

## 7. COPYING

Copyright (C) 2011 Steven Armstrong. Free use of this software is granted under the terms of the GNU General Public License version 3 (GPLv3).